import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, max, format, extent } from 'd3';
import ReactDropdown from 'react-dropdown';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const attributes2=[{value: 'GRAD', label: 'GRAD' }];

const attributes3 = [
  { value: 'Sarajevo', label: 'Sarajevo' },
  { value: 'Banja Luka', label: 'Banja Luka'},
  { value: 'Bijeljina', label: 'Bijeljina' },
  { value: 'Pale', label: 'Pale' },
  { value: 'Gradiška', label: 'Gradiška' },
  { value: 'Doboj', label: 'Doboj' },
  { value: 'Pale', label: 'Pale'},
  { value: 'Brcko', label: 'Brcko'},
  { value: 'Trebinje', label: 'Trebinje'},
  { value: 'Kozarska Dubica', label: 'Kozarska Dubica' },
  { value: 'Foča', label: 'Foča' },
  { value: 'Mostar', label: 'Mostar'},
  { value: 'Teslić', label: 'Teslić' },
  { value: 'Laktaši', label: 'Laktaši"' },
  { value: 'Istočno Sarajevo', label: 'Istočno Sarajevo'},
  { value: 'Doboj', label: 'Doboj' },
  { value: 'Pale', label: 'Pale'},
  { value: 'Brčko', label: 'Brčko'},
  { value: 'Trebinje', label: 'Trebinje'},
  { value: 'Kozarska Dubica', label: 'Kozarska Dubica' }
];
const kategorija = [
  { value: 'sepal_length', label: 'Sepal Length' },
  { value: 'sepal_width', label: 'Sepal Width' },
  { value: 'petal_length', label: 'Petal Length' },
  { value: 'petal_width', label: 'Petal Width' },
  { value: 'species', label: 'Species' }
];

const getLabel = value => {
  for (let i = 0; i < kategorija.length; i++) {
    if (kategorija[i].value === value) {
      return kategorija[i].label;
    }
  }
};
const getLabel2 = value => {
  for (let i = 0; i < attributes2.length; i++) {
    if (attributes2[i].value === value) {
      return attributes2[i].label;
    }
  }
};


const App = () => {
  const data = useData();

  const initialXAttribute = 'GRAD';
 const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
  const xAxisLabel = getLabel2(xAttribute);

  const initialYAttribute = 'sepal_width';
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute);

  if (!data) {
    return <pre>Loading...(data?)</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight]);
  
  /* 
  sad ya sad druga koordinata se nece mijenjati
  
  <span className="dropdown-label">X</span>
        <ReactDropdown
          options={attributes}
          value={xAttribute}
          onChange={({ value }) => setXAttribute(value)}
        />*/

  return (
    <>
      <div className="menus-container">
       
        <span className="dropdown-label">Kategorija</span>
        <ReactDropdown
          options={kategorija}
          value={yAttribute}
          onChange={({ value }) => setYAttribute(value)}
        />
      </div>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {yAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <Marks
            data={data}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            tooltipFormat={xAxisTickFormat}
           // circleRadius={1}
          />
        </g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, ro